==> rustc-1.77_1.77.2+dfsg1ubuntu1.orig.tar.xz: rustc-1.77.2-src/src/tools/clippy/tests/ui/cast_lossless_integer.rs <==
#![allow(clippy::no_effect, clippy::unnecessary_operation, dead_code)]
#![warn(clippy::cast_lossless)]

fn main() {
    // Test clippy::cast_lossless with casts to integer types
    let _ = 1i8 as i16;
    let _ = 1i8 as i32;
    let _ = 1i8 as i64;
    let _ = 1u8 as i16;
    let _ = 1u8 as i32;
    let _ = 1u8 as i64;
    let _ = 1u8 as u16;
    let _ = 1u8 as u32;
    let _ = 1u8 as u64;
    let _ = 1i16 as i32;
    let _ = 1i16 as i64;
    let _ = 1u16 as i32;
    let _ = 1u16 as i64;
    let _ = 1u16 as u32;
    let _ = 1u16 as u64;
    let _ = 1i32 as i64;
    let _ = 1u32 as i64;
    let _ = 1u32 as u64;

    // Test with an expression wrapped in parens
    let _ = (1u8 + 1u8) as u16;
}

// The lint would suggest using `f64::from(input)` here but the `XX::from` function is not const,
// so we skip the lint if the expression is in a const fn.
// See #3656
const fn abc(input: u16) -> u32 {
    input as u32
}

// Same as the above issue. We can't suggest `::from` in const fns in impls
mod cast_lossless_in_impl {
    struct A;

    impl A {
        pub const fn convert(x: u32) -> u64 {
            x as u64
        }
    }
}

#[derive(PartialEq, Debug)]
#[repr(i64)]
enum Test {
    A = u32::MAX as i64 + 1,
}

fn issue11458() {
    macro_rules! sign_cast {
        ($var: ident, $src: ty, $dest: ty) => {
            <$dest>::from_ne_bytes(($var as $src).to_ne_bytes())
        };
    }
    let x = 10_u128;
    let _ = sign_cast!(x, u8, i8) as i32;
    let _ = (sign_cast!(x, u8, i8) + 1) as i32;
}

==> rustc-1.80_1.80.1+dfsg0ubuntu1.orig.tar.xz: rustc-1.80.1-src/src/tools/clippy/tests/ui/cast_lossless_integer.rs <==
#![allow(clippy::no_effect, clippy::unnecessary_operation, dead_code)]
#![warn(clippy::cast_lossless)]

type I64 = i64;
type U128 = u128;

fn main() {
    // Test clippy::cast_lossless with casts to integer types
    let _ = 1i8 as i16;
    let _ = 1i8 as i32;
    let _ = 1i8 as i64;
    let _ = 1u8 as i16;
    let _ = 1u8 as i32;
    let _ = 1u8 as i64;
    let _ = 1u8 as u16;
    let _ = 1u8 as u32;
    let _ = 1u8 as u64;
    let _ = 1i16 as i32;
    let _ = 1i16 as i64;
    let _ = 1u16 as i32;
    let _ = 1u16 as i64;
    let _ = 1u16 as u32;
    let _ = 1u16 as u64;
    let _ = 1i32 as i64;
    let _ = 1u32 as i64;
    let _ = 1u32 as u64;

    // Test with an expression wrapped in parens
    let _ = (1u8 + 1u8) as u16;

    let _ = 1i8 as I64;

    // Do not lint if destination type is u128
    // see https://github.com/rust-lang/rust-clippy/issues/12492
    let _ = 1u8 as u128;
    let _ = 1u8 as U128;
}

// The lint would suggest using `f64::from(input)` here but the `XX::from` function is not const,
// so we skip the lint if the expression is in a const fn.
// See #3656
const fn abc(input: u16) -> u32 {
    input as u32
}

// Same as the above issue. We can't suggest `::from` in const fns in impls
mod cast_lossless_in_impl {
    struct A;

    impl A {
        pub const fn convert(x: u32) -> u64 {
            x as u64
        }
    }
}

#[derive(PartialEq, Debug)]
#[repr(i64)]
enum Test {
    A = u32::MAX as i64 + 1,
}

fn issue11458() {
    macro_rules! sign_cast {
        ($var: ident, $src: ty, $dest: ty) => {
            <$dest>::from_ne_bytes(($var as $src).to_ne_bytes())
        };
    }
    let x = 10_u128;
    let _ = sign_cast!(x, u8, i8) as i32;
    let _ = (sign_cast!(x, u8, i8) + 1) as i32;
}
